@@ -15,6 +15,8 @@
 from six import string_types
 
 import os
+import random
+import sys
 
 from robot import utils
 from robot.errors import DataError, FrameworkError
@@ -156,17 +158,25 @@ class _BaseSettings(object):
             raise DataError("Default visible log level '%s' is lower than "
                             "log level '%s'" % (default, log_level))
 
-    def _process_randomize_value(self, original_value):
-        formatted_value = original_value.lower()
-        if formatted_value in ('test', 'suite'):
-            formatted_value += 's'
-        if formatted_value not in ('tests', 'suites', 'none', 'all'):
-            self._raise_invalid_option_value('--randomize', original_value)
-        return formatted_value
+    def _process_randomize_value(self, original):
+        value = original.lower()
+        if ':' in value:
+            value, seed = value.split(':', 1)
+        else:
+            seed = random.randint(0, sys.maxsize)
+        if value in ('test', 'suite'):
+            value += 's'
+        if value not in ('tests', 'suites', 'none', 'all'):
+            self._raise_invalid_option_value('--randomize', original)
+        try:
+            seed = int(seed)
+        except ValueError:
+            self._raise_invalid_option_value('--randomize', original)
+        return value, seed
 
     def _raise_invalid_option_value(self, option_name, given_value):
-        raise DataError("Option '%s' does not support value '%s'." %
-                        (option_name, given_value))
+        raise DataError("Option '%s' does not support value '%s'."
+                        % (option_name, given_value))
 
     def _process_runmode_value(self, original_value):
         formatted_value = original_value.lower()
@@ -417,17 +427,22 @@ class RobotSettings(_BaseSettings):
             'include_tests': self['TestNames'],
             'empty_suite_ok': self['RunEmptySuite'],
             'randomize_suites': self.randomize_suites,
-            'randomize_tests': self.randomize_tests
+            'randomize_tests': self.randomize_tests,
+            'randomize_seed': self.randomize_seed,
         }
 
+    @property
+    def randomize_seed(self):
+        return self['Randomize'][1]
+
     @property
     def randomize_suites(self):
-        return (self['Randomize'] in ('suites', 'all') or
+        return (self['Randomize'][0] in ('suites', 'all') or
                 any(mode in ('random:suite', 'random:all') for mode in self['RunMode']))
 
     @property
     def randomize_tests(self):
-        return (self['Randomize'] in ('tests', 'all') or
+        return (self['Randomize'][0] in ('tests', 'all') or
                 any(mode in ('random:test', 'random:all') for mode in self['RunMode']))
 
     @property
