@@ -1,4 +1,4 @@
-#  Copyright 2008-2013 Nokia Siemens Networks Oyj
+#  Copyright 2008-2014 Nokia Solutions and Networks
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -12,6 +12,8 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from six import PY3, string_types, text_type as unicode
+
 import sys
 
 from robot.api import logger
@@ -377,7 +379,7 @@ class _List:
             name = ' (%s)' % names[index] if index in names else ''
             try:
                 assert_equals(item1, item2, msg='Index %d%s' % (index, name))
-            except AssertionError, err:
+            except AssertionError as err:
                 yield unic(err)
 
     def list_should_contain_sub_list(self, list1, list2, msg=None, values=True):
@@ -529,7 +531,7 @@ class _Dictionary:
         #TODO: Sorting causes problems when key types are not comparable,
         # especially in Python 3 where even basic types like int and str
         # are not comparable to each other.
-        if sys.version_info[0] == 3:
+        if PY3:
             return list(dictionary)
         return sorted(dictionary)
 
@@ -710,7 +712,7 @@ class _Dictionary:
         for key in keys:
             try:
                 assert_equals(dict1[key], dict2[key], msg='Key %s' % (key,))
-            except AssertionError, err:
+            except AssertionError as err:
                 yield unic(err)
 
 
@@ -772,6 +774,6 @@ def _verify_condition(condition, default_msg, given_msg, include_default=False):
         raise AssertionError(given_msg)
 
 def _include_default_message(include):
-    if isinstance(include, basestring):
+    if isinstance(include, string_types):
         return include.lower() not in ['no values', 'false']
     return bool(include)
