@@ -1,4 +1,4 @@
-#  Copyright 2008-2013 Nokia Siemens Networks Oyj
+#  Copyright 2008-2014 Nokia Solutions and Networks
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -12,6 +12,8 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+from six import PY3
+
 import sys
 
 from robot.utils import NormalizedDict
@@ -26,10 +28,10 @@ class Metadata(NormalizedDict):
         return u'{%s}' % ', '.join('%s: %s' % (k, self[k]) for k in self)
 
     def __str__(self):
-        if sys.version_info[0] == 3:
+        if PY3:
             return self.__unicode__()
         return unicode(self).encode('ASCII', 'replace')
 
-    if sys.version_info[0] == 3:
-        def __bytes__(self):
-            return str(self).encode('ASCII', 'replace')
+    #PY3
+    def __bytes__(self):
+        return str(self).encode('ASCII', 'replace')
