@@ -1,4 +1,4 @@
-#  Copyright 2008-2013 Nokia Siemens Networks Oyj
+#  Copyright 2008-2014 Nokia Solutions and Networks
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -33,4 +33,4 @@ class ArgumentSpec(object):
 
     @property
     def maxargs(self):
-        return len(self.positional) if not self.varargs else sys.maxint
+        return len(self.positional) if not self.varargs else sys.maxsize
